Type: Package
Package: remify
Title: Processing and Transforming Relational Event History Data
Version: 4.1.0
Date: 2026-07-11
Authors@R: 
    c(person(given = "Giuseppe",
             family = "Arena",
             role = c("aut", "cre"),
             email = "g.arena@uva.nl",
             comment = c(ORCID = "0000-0001-5204-3326")),
      person(given = "Joris",
             family = "Mulder",
             role = "aut",
             email = "j.mulder3@tilburguniversity.edu"),
      person(given = "Rumana",
             family = "Lakdawala",
             role = "ctb"),
      person(given = "Marlyne",
             family = "Meijerink-Bosman",
             role = "ctb"),
      person(given = "Diana",
             family = "Karimova",
             role = "ctb"),
      person(given = "Fabio",
             family = "Generoso Vieira",
             role = "ctb"),
      person(given = "Mahdi",
             family = "Shafiee Kamalabad",
             role = "ctb"),
      person(given = "Roger",
             family = "Leenders",
             role = "ctb",
             email = "r.t.a.j.leenders@tilburguniversity.edu"))
Maintainer: Giuseppe Arena <g.arena@uva.nl>
Description: Efficiently processes relational event history data and transforms them into formats suitable for other packages. The primary objective of this package is to convert event history data into a format that integrates with the packages in 'remverse' and is compatible with various analytical tools (e.g., computing network statistics, estimating tie-oriented or actor-oriented social network models). Second, it can also transform the data into formats compatible with other packages out of 'remverse'. The package processes the data for two types of temporal social network models: tie-oriented modeling framework (Butts, C., 2008, <doi:10.1111/j.1467-9531.2008.00203.x>) and actor-oriented modeling framework (Stadtfeld, C., & Block, P., 2017, <doi:10.15195/v4.a14>). 
License: MIT + file LICENSE
URL: https://tilburgnetworkgroup.github.io/remify/
BugReports: https://github.com/TilburgNetworkGroup/remify/issues
Depends: R (>= 4.0.0)
Imports: Rcpp (>= 1.0.8.3), igraph (>= 1.4.3)
Suggests: knitr, rmarkdown, tinytest, remstats
LinkingTo: Rcpp, RcppArmadillo,
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
LazyDataCompression: gzip
NeedsCompilation: yes
Packaged: 2026-07-11 10:15:13 UTC; jorismulder
Author: Giuseppe Arena [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5204-3326>),
  Joris Mulder [aut],
  Rumana Lakdawala [ctb],
  Marlyne Meijerink-Bosman [ctb],
  Diana Karimova [ctb],
  Fabio Generoso Vieira [ctb],
  Mahdi Shafiee Kamalabad [ctb],
  Roger Leenders [ctb]
Repository: CRAN
Date/Publication: 2026-07-13 12:10:02 UTC
Built: R 4.6.1; aarch64-apple-darwin23; 2026-07-13 14:18:57 UTC; unix
Archs: remify.so.dSYM
