# Generated by roxygen2: do not edit by hand

S3method(dim,remify)
S3method(plot,remify)
S3method(print,remify)
S3method(print,remify_durem)
S3method(summary,remify)
S3method(summary,remify_durem)
export(is.remify_durem)
export(remify)
import(grDevices)
import(graphics)
import(stats)
importFrom(Rcpp,sourceCpp)
useDynLib(remify, .registration = TRUE)
