# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

remifyCpp <- function(input_edgelist, actors, types, directed, ordinal, origin, omit_dyad, model, active = FALSE, ncores = 1L) {
    .Call(`_remify_remifyCpp`, input_edgelist, actors, types, directed, ordinal, origin, omit_dyad, model, active, ncores)
}

getEventsComposition <- function(dyads, N, D, directed, ncores) {
    .Call(`_remify_getEventsComposition`, dyads, N, D, directed, ncores)
}

getDyadIndex_cpp <- function(actor1, actor2, type, N, directed) {
    .Call(`_remify_getDyadIndex_cpp`, actor1, actor2, type, N, directed)
}

remify2relventrem <- function(actor1, actor2, type, dyad, M, N, D, with_type, directed, model, omit_dyad, ncores = 1L) {
    .Call(`_remify_remify2relventrem`, actor1, actor2, type, dyad, M, N, D, with_type, directed, model, omit_dyad, ncores)
}

getOmitDyadManualRiskSet3 <- function(model, actor1, actor2, type, manual_riskset, actorName, typeName, D, N, directed, extend_riskset_by_type, ncores) {
    .Call(`_remify_getOmitDyadManualRiskSet3`, model, actor1, actor2, type, manual_riskset, actorName, typeName, D, N, directed, extend_riskset_by_type, ncores)
}

remifyCpp2 <- function(input_edgelist, actors, types, directed, ordinal, origin, omit_dyad, model, active, manual_riskset, extend_riskset_by_type = TRUE, ncores = 1L) {
    .Call(`_remify_remifyCpp2`, input_edgelist, actors, types, directed, ordinal, origin, omit_dyad, model, active, manual_riskset, extend_riskset_by_type, ncores)
}

remify2relventremIdx <- function(actor1, actor2, type, dyad, M, N, D, with_type, directed, model, omit_dyad, ncores = 1L) {
    .Call(`_remify_remify2relventremIdx`, actor1, actor2, type, dyad, M, N, D, with_type, directed, model, omit_dyad, ncores)
}

